@@ -1,10 +1,31 @@
+#######################################################################
+# TSP - Traveling Salesperson Problem 
+# Copyrigth (C) 2011 Michael Hahsler and Kurt Hornik
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
+
+
 ## create a (asymmetric) ATSP problem
 ATSP <- function(x, labels = NULL) {
     if(inherits(x, "ATSP")) return(x)
 
-    x <- as.ATSP(x)
-    if(!is.null(labels)) dimnames(x) <- list(labels, labels)
-    x
+    atsp <- as.ATSP(x)
+    
+    if(!is.null(labels)) dimnames(atps) <- list(labels, labels)
+    atsp
 }
 
 as.ATSP <- function(object) UseMethod("as.ATSP")
@@ -19,6 +40,8 @@ as.ATSP.matrix <- function(object){
     ## make sure we have labels
     if(is.null(dimnames(object))) 
         dimnames(object) <- list(1:dim(object)[1], 1: dim(object)[1])
+    if(is.null(colnames(object)))  colnames(object) <- rownames(object)
+    if(is.null(rownames(object)))  rownames(object) <- colnames(object)
 
     class(object) <- c("ATSP", class(object))
     object
